generate_module_tree

Function generate_module_tree 

pub fn generate_module_tree(
    tree: &ModuleTree,
    project_name: &str,
) -> GeneratedProject
Generate Rust code from a module tree (multi-file project).

This flattens all modules into a single Rust file, generating all agents and functions with appropriate visibility modifiers.