pub fn generate_module_tree_with_config(
tree: &ModuleTree,
project_name: &str,
runtime_dep: RuntimeDep,
) -> GeneratedProjectExpand description
Generate Rust code from a module tree with custom runtime dependency.
pub fn generate_module_tree_with_config(
tree: &ModuleTree,
project_name: &str,
runtime_dep: RuntimeDep,
) -> GeneratedProjectGenerate Rust code from a module tree with custom runtime dependency.